@@ -1,5 +1,6 @@
-from rest_framework import viewsets
+from rest_framework import response, status, viewsets
 
+from whisperer.exceptions import WebhookAlreadyRegistered
 from whisperer.models import Webhook, WebhookEvent
 from whisperer.resources.filters import WebhookEventFilter, WebhookFilter
 from whisperer.resources.serializers import WebhookEventSerializer, WebhookSerializer
@@ -16,6 +17,22 @@ class WebhookViewSet(viewsets.ModelViewSet):
         queryset = super(WebhookViewSet, self).get_queryset()
         return queryset.filter(user=self.request.user)
 
+    def create(self, request, *args, **kwargs):
+        serializer = self.get_serializer(data=request.data)
+        serializer.is_valid(raise_exception=True)
+
+        try:
+            self.perform_create(serializer)
+        except WebhookAlreadyRegistered as exception:
+            return response.Response(
+                data=exception.code, status=status.HTTP_406_NOT_ACCEPTABLE
+            )
+
+        headers = self.get_success_headers(serializer.data)
+        return response.Response(
+            serializer.data, status=status.HTTP_201_CREATED, headers=headers
+        )
+
     def perform_create(self, serializer):
         user = self.request.user
         serializer.instance = self.service.register_webhook(
