@@ -19,16 +19,19 @@ class WebhookService(object):
 
     def update_webhook(self, webhook, user, *args, **kwargs):
         webhook.user = user
-        target_url = kwargs.get('target_url')
-        event_type = kwargs.get('event_type')
+        target_url = kwargs.get('target_url', webhook.target_url)
+        event_type = kwargs.get('event_type', webhook.event_type)
         try:
-            Webhook.objects.get(user=user, target_url=target_url, event_type=event_type)
+            Webhook.objects.exclude(id=webhook.id).get(
+                user=user, target_url=target_url, event_type=event_type
+            )
             raise WebhookAlreadyRegistered()
         except Webhook.DoesNotExist:
             pass
+
         for attr, value in kwargs.items():
             setattr(webhook, attr, value)
-        webhook.save()
+        webhook.save(update_fields=kwargs.keys())
         return webhook
 
     def delete_webhook(self, webhook):
