@@ -34,17 +34,17 @@ from whisperer.utils import LockTask
 
 class WebhookTestCase(TestCase):
     def setUp(self):
-        self.user = mommy.make(User, username='test_user')
+        self.user = mommy.make(User, username="test_user")
         self.service = WebhookService()
 
     def test_register_webhook(self):
         webhook = mommy.prepare(
             Webhook,
             user=self.user,
-            target_url='http://example.com/order_create',
-            secret_key='secret',
-            event_type='order-created',
-            retry_countdown_config={'choice': 'exponential', 'kwargs': {'base': 2}},
+            target_url="http://example.com/order_create",
+            secret_key="secret",
+            event_type="order-created",
+            retry_countdown_config={"choice": "exponential", "kwargs": {"base": 2}},
         )
 
         serializer = WebhookSerializer(webhook)
@@ -53,7 +53,7 @@ class WebhookTestCase(TestCase):
         webhook = self.service.register_webhook(
             user=self.user, **serializer.validated_data
         )
-        self.assertEqual(webhook.event_type, 'order-created')
+        self.assertEqual(webhook.event_type, "order-created")
 
         with self.assertRaises(WebhookAlreadyRegistered):
             self.service.register_webhook(user=self.user, **serializer.validated_data)
@@ -62,10 +62,10 @@ class WebhookTestCase(TestCase):
         webhook = mommy.prepare(
             Webhook,
             user=self.user,
-            target_url='http://example2.com/order_create',
-            secret_key='secret',
-            event_type='order-created',
-            retry_countdown_config={'choice': 'exponential', 'kwargs': {'base': 2}},
+            target_url="http://example2.com/order_create",
+            secret_key="secret",
+            event_type="order-created",
+            retry_countdown_config={"choice": "exponential", "kwargs": {"base": 2}},
         )
 
         serializer = WebhookSerializer(webhook)
@@ -76,11 +76,11 @@ class WebhookTestCase(TestCase):
         )
 
         update_data = {
-            'target_url': 'http://example3.com/order_update',
-            'event_type': 'order-update',
-            'retry_countdown_config': {
-                'choice': 'linear',
-                'kwargs': {'base': 1 * 60, 'limit': 5 * 60},
+            "target_url": "http://example3.com/order_update",
+            "event_type": "order-update",
+            "retry_countdown_config": {
+                "choice": "linear",
+                "kwargs": {"base": 1 * 60, "limit": 5 * 60},
             },
         }
         webhook_updated = self.service.update_webhook(
@@ -90,53 +90,57 @@ class WebhookTestCase(TestCase):
         self.assertNotEqual(webhook.target_url, webhook_updated.target_url)
         self.assertNotEqual(webhook.event_type, webhook_updated.event_type)
 
-        self.assertEqual(webhook_updated.target_url, update_data['target_url'])
-        self.assertEqual(webhook_updated.event_type, 'order-update')
+        self.assertEqual(webhook_updated.target_url, update_data["target_url"])
+        self.assertEqual(webhook_updated.event_type, "order-update")
 
     def test_update_webhook_with_already_registered_one(self):
         webhook = mommy.make(
             Webhook,
             user=self.user,
-            target_url='http://example2.com/order_create',
-            secret_key='secret',
-            event_type='order-created',
-            retry_countdown_config={'choice': 'exponential', 'kwargs': {'base': 2}},
+            target_url="http://example2.com/order_create",
+            secret_key="secret",
+            event_type="order-created",
+            retry_countdown_config={"choice": "exponential", "kwargs": {"base": 2}},
         )
 
         mommy.make(
             Webhook,
             user=self.user,
-            target_url='http://example2.com/order_create',
-            secret_key='secret',
-            event_type='order-update',
-            retry_countdown_config={'choice': 'exponential', 'kwargs': {'base': 2}},
+            target_url="http://example2.com/order_create",
+            secret_key="secret",
+            event_type="order-update",
+            retry_countdown_config={"choice": "exponential", "kwargs": {"base": 2}},
         )
 
-        update_data = {'target_url': webhook.target_url, 'event_type': 'order-update'}
+        update_data = {"target_url": webhook.target_url, "event_type": "order-update"}
 
         with self.assertRaises(WebhookAlreadyRegistered):
             self.service.update_webhook(webhook, self.user, **update_data)
 
-        del update_data['target_url']
+        del update_data["target_url"]
 
         with self.assertRaises(WebhookAlreadyRegistered):
             self.service.update_webhook(webhook, self.user, **update_data)
 
         update_data = {
-            'retry_countdown_config': {
-                'choice': 'linear',
-                'kwargs': {'base': 1 * 60, 'limit': 10 * 60},
+            "retry_countdown_config": {
+                "choice": "linear",
+                "kwargs": {"base": 1 * 60, "limit": 10 * 60},
             },
         }
 
         webhook_updated = self.service.update_webhook(webhook, self.user, **update_data)
         self.assertEqual(
-            webhook_updated.retry_countdown_config['kwargs'],
-            update_data['retry_countdown_config']['kwargs'],
+            webhook_updated.retry_countdown_config["kwargs"],
+            update_data["retry_countdown_config"]["kwargs"],
         )
 
     def test_delete_webhook(self):
-        webhook = mommy.make(Webhook, is_active=True)
+        webhook = mommy.make(
+            Webhook,
+            is_active=True,
+            retry_countdown_config={"choice": "exponential", "kwargs": {"base": 2}},
+        )
         self.service.delete_webhook(webhook)
         webhook.refresh_from_db()
         self.assertFalse(webhook.is_active)
@@ -145,30 +149,30 @@ class WebhookTestCase(TestCase):
 @override_settings(CELERY_ALWAYS_EAGER=True)
 class WhispererEventTestCase(TestCase):
     def setUp(self):
-        self.target_url = 'http://example.com/order_create'
-        self.user = mommy.make(User, username='test_user')
+        self.target_url = "http://example.com/order_create"
+        self.user = mommy.make(User, username="test_user")
 
         self.webhook = mommy.make(
             Webhook,
             user=self.user,
             target_url=self.target_url,
-            secret_key='secret',
-            event_type='order-created',
-            retry_countdown_config={'choice': 'exponential', 'kwargs': {'base': 2}},
+            secret_key="secret",
+            event_type="order-created",
+            retry_countdown_config={"choice": "exponential", "kwargs": {"base": 2}},
         )
-        self.target_url2 = 'http://example.com/auth_order_update'
+        self.target_url2 = "http://example.com/auth_order_update"
         self.webhook2 = mommy.make(
             Webhook,
             user=self.user,
             target_url=self.target_url2,
-            secret_key='secret',
-            event_type='order-updated',
-            retry_countdown_config={'choice': 'exponential', 'kwargs': {'base': 2}},
+            secret_key="secret",
+            event_type="order-updated",
+            retry_countdown_config={"choice": "exponential", "kwargs": {"base": 2}},
             config={
-                'auth': {
-                    'username': 'username',
-                    'password': '123',
-                    'auth_type': 'basic',
+                "auth": {
+                    "username": "username",
+                    "password": "123",
+                    "auth_type": "basic",
                 }
             },
         )
@@ -178,16 +182,16 @@ class WhispererEventTestCase(TestCase):
             Order,
             customer=self.customer,
             address=self.address,
-            number='1',
-            amount='1',
-            discount_amount='1',
-            shipping_amount='1',
+            number="1",
+            amount="1",
+            discount_amount="1",
+            shipping_amount="1",
         )
 
     def test_deliver_event(self):
         with requests_mock.Mocker() as mock:
             mock.register_uri(
-                'POST', self.target_url, text='Order Created', status_code=200
+                "POST", self.target_url, text="Order Created", status_code=200
             )
             self.order.save()
             webhook_events = WebhookEvent.objects.all()
@@ -206,10 +210,10 @@ class WhispererEventTestCase(TestCase):
         )
         with requests_mock.Mocker() as mock:
             mock.register_uri(
-                'POST', self.webhook.target_url, text='Order Created', status_code=200
+                "POST", self.webhook.target_url, text="Order Created", status_code=200
             )
             deliver_event(
-                self.order, 'order-created', async_=False, event_uuid=webhookevent.uuid
+                self.order, "order-created", async_=False, event_uuid=webhookevent.uuid
             )
             webhookevent.refresh_from_db()
             self.assertTrue(webhookevent.delivered)
@@ -226,15 +230,15 @@ class WhispererEventTestCase(TestCase):
         )
         with requests_mock.Mocker() as mock:
             mock.register_uri(
-                'POST', self.webhook.target_url, text='Order Created', status_code=200
+                "POST", self.webhook.target_url, text="Order Created", status_code=200
             )
-            deliver_event(self.order, 'order-created', event_uuid=webhookevent.uuid)
+            deliver_event(self.order, "order-created", event_uuid=webhookevent.uuid)
             webhookevent.refresh_from_db()
             self.assertTrue(webhookevent.delivered)
 
-    @mock.patch('requests.post')
+    @mock.patch("requests.post")
     def test_http_error(self, post_mock):
-        post_mock.side_effect = requests.exceptions.HTTPError('HTTPError')
+        post_mock.side_effect = requests.exceptions.HTTPError("HTTPError")
         self.order.save()
         webhook_events = WebhookEvent.objects.all()
         self.assertEqual(len(webhook_events), 1)
@@ -242,7 +246,7 @@ class WhispererEventTestCase(TestCase):
         self.assertEqual(webhook_events[0].response_http_status, 500)
         self.assertIn("HTTPError", webhook_events[0].response_content)
 
-    @mock.patch('requests.post')
+    @mock.patch("requests.post")
     def test_unboundlocal_error(self, post_mock):
         post_mock.side_effect = UnboundLocalError()
         self.order.save()
@@ -258,10 +262,10 @@ class WhispererEventTestCase(TestCase):
         webhook = mommy.make(
             Webhook,
             user=self.user,
-            target_url='http://example.com/order_update',
-            secret_key='secret',
-            event_type='order-created',
-            retry_countdown_config={'choice': 'exponential', 'kwargs': {'base': 2}},
+            target_url="http://example.com/order_update",
+            secret_key="secret",
+            event_type="order-created",
+            retry_countdown_config={"choice": "exponential", "kwargs": {"base": 2}},
         )
         # unsuitable for event scanner query because of  retry limit
         webhookevent1 = mommy.make(
@@ -314,10 +318,10 @@ class WhispererEventTestCase(TestCase):
 
         with requests_mock.Mocker() as mock:
             mock.register_uri(
-                'POST',
-                'http://example.com/order_update',
+                "POST",
+                "http://example.com/order_update",
                 [
-                    {'text': 'Order created', 'status_code': 200},
+                    {"text": "Order created", "status_code": 200},
                 ],
             )
             undelivered_event_scanner()
@@ -356,7 +360,7 @@ class WhispererEventTestCase(TestCase):
         )
         with requests_mock.Mocker() as mock:
             mock.register_uri(
-                'POST', self.target_url, [{'text': 'Bad request', 'status_code': 400}]
+                "POST", self.target_url, [{"text": "Bad request", "status_code": 400}]
             )
             mock_method.return_value = False
             deliver_event_task.delay(
@@ -371,7 +375,7 @@ class WhispererEventTestCase(TestCase):
         # test new event
         with requests_mock.Mocker() as mock:
             mock.register_uri(
-                'POST', self.target_url, [{'text': 'Bad request', 'status_code': 400}]
+                "POST", self.target_url, [{"text": "Bad request", "status_code": 400}]
             )
             self.order.save()
 
@@ -389,9 +393,9 @@ class WhispererEventTestCase(TestCase):
 
         with requests_mock.Mocker() as mock:
             mock.register_uri(
-                'POST',
+                "POST",
                 self.target_url,
-                [{'text': 'Order event received', 'status_code': 200}],
+                [{"text": "Order event received", "status_code": 200}],
             )
             WebhookEvent.objects.filter(
                 id__in=[webhookevent1.id, webhookevent2.id]
@@ -412,9 +416,9 @@ class WhispererEventTestCase(TestCase):
     def test_auth_config(self, m, mock_method):
         mock_method.return_value = False
         self.order.save()
-        self.order.number = '123'
+        self.order.number = "123"
         m.register_uri(
-            'POST', self.target_url2, text=self._auth_test_callback, status_code=200
+            "POST", self.target_url2, text=self._auth_test_callback, status_code=200
         )
         self.order.save()
         event = WebhookEvent.objects.filter(webhook=self.webhook2).last()
@@ -424,36 +428,36 @@ class WhispererEventTestCase(TestCase):
         self.webhook2.config = {}
         self.webhook2.save()
 
-        self.order.number = '123123'
+        self.order.number = "123123"
         self.order.save()
         event = WebhookEvent.objects.filter(webhook=self.webhook2).last()
         self.assertEqual(event.response_http_status, 401)
         self.assertFalse(event.delivered)
 
     def _auth_test_callback(self, request, context):
-        if 'Authorization' not in request.headers:
+        if "Authorization" not in request.headers:
             context.status_code = 401
-        return ''
+        return ""
 
 
 def dummy_whisperer_event_callback(response, event_type, instance, payload):
-    """ this function creates customer in test database """
+    """this function creates customer in test database"""
     mommy.make(Customer)
 
 
 @override_settings(CELERY_ALWAYS_EAGER=True)
 class WhispererEventCallbackTestCase(TestCase):
     def setUp(self):
-        self.target_url = 'http://example.com/foo_bar'
-        user = mommy.make(User, username='test_user')
+        self.target_url = "http://example.com/foo_bar"
+        user = mommy.make(User, username="test_user")
         mommy.make(
             Webhook,
             user=user,
             target_url=self.target_url,
-            secret_key='secret',
-            event_type='order-created',
-            retry_countdown_config={'choice': 'exponential', 'kwargs': {'base': 2}},
-            callback='whisperer.tests.tests.dummy_whisperer_event_callback',
+            secret_key="secret",
+            event_type="order-created",
+            retry_countdown_config={"choice": "exponential", "kwargs": {"base": 2}},
+            callback="whisperer.tests.tests.dummy_whisperer_event_callback",
         )
         customer = mommy.make(Customer)
         address = mommy.make(Address)
@@ -461,10 +465,10 @@ class WhispererEventCallbackTestCase(TestCase):
             Order,
             customer=customer,
             address=address,
-            number='1',
-            amount='1',
-            discount_amount='1',
-            shipping_amount='1',
+            number="1",
+            amount="1",
+            discount_amount="1",
+            shipping_amount="1",
         )
 
     def tearDown(self):
@@ -473,7 +477,7 @@ class WhispererEventCallbackTestCase(TestCase):
     def test_runs_callback(self):
         with requests_mock.Mocker() as mock:
             mock.register_uri(
-                'POST', self.target_url, text='Request Processed', status_code=200
+                "POST", self.target_url, text="Request Processed", status_code=200
             )
 
             # before callback we have one customer
@@ -529,15 +533,16 @@ class RetryCountdownTestCase(TestCase):
 
     def test_exponential_retry_countdown(self):
         base = 2
-        countdown = ExponentialRetryCountdown(base=base)
+        factor = 16
+        countdown = ExponentialRetryCountdown(base=base, factor=factor)
         for _ in range(15):
             retry_count = random.randint(1, 12)
             value = countdown.get_value(retry_count)
-            self.assertEqual(value, base ** retry_count)
+            self.assertEqual(value, (base ** retry_count) * factor)
 
         limit = 20 * 60
-        countdown = ExponentialRetryCountdown(base=base, limit=limit)
+        countdown = ExponentialRetryCountdown(base=base, factor=factor, limit=limit)
         for _ in range(15):
             retry_count = random.randint(1, 12)
             value = countdown.get_value(retry_count)
-            self.assertEqual(value, min(base ** retry_count, limit))
+            self.assertEqual(value, min((base ** retry_count) * factor, limit))
